pub struct CleanApertureBox {
pub clean_aperture_width_n: u32,
pub clean_aperture_width_d: u32,
pub clean_aperture_height_n: u32,
pub clean_aperture_height_d: u32,
pub horiz_off_n: u32,
pub horiz_off_d: u32,
pub vert_off_n: u32,
pub vert_off_d: u32,
}Expand description
Clean Aperture Box (clap) — ISO/IEC 14496-12:2015 12.1.4.2.
Defines the clean aperture width, height, and offset as fractions (N/D). For horizOff and vertOff, D must be positive and N may be positive or negative. For cleanApertureWidth and cleanApertureHeight, both N and D must be positive.
Fields
clean_aperture_width_n: u32clean_aperture_width_d: u32clean_aperture_height_n: u32clean_aperture_height_d: u32horiz_off_n: u32horiz_off_d: u32vert_off_n: u32vert_off_d: u32Trait Implementations
Sourceimpl Clone for CleanApertureBox
impl Clone for CleanApertureBox
Sourcefn clone(&self) -> CleanApertureBox
fn clone(&self) -> CleanApertureBox
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CleanApertureBox
Sourceimpl Debug for CleanApertureBox
impl Debug for CleanApertureBox
impl Eq for CleanApertureBox
Sourceimpl<'a> Parse<'a> for CleanApertureBox
impl<'a> Parse<'a> for CleanApertureBox
Sourceimpl PartialEq for CleanApertureBox
impl PartialEq for CleanApertureBox
Sourceimpl Serialize for CleanApertureBox
impl Serialize for CleanApertureBox
Sourceimpl Serialize for CleanApertureBox
impl Serialize for CleanApertureBox
Sourcetype Error = Error
type Error = Error
The error type this implementer returns (usually the same as the
corresponding
Parse impl, but need not be).Sourcefn serialized_len(&self) -> usize
fn serialized_len(&self) -> usize
Number of bytes
serialize_into will write.impl StructuralPartialEq for CleanApertureBox